@@ -6,6 +6,7 @@ pub struct Opts {
     pub table: String,
     pub field: Option<String>,
     pub set: Option<String>,
+    pub bump: Option<String>,
 }
 
 const DEFAULT_PATH: &str = "Cargo.toml";
@@ -48,6 +49,13 @@ pub fn start_command() -> Opts {
                         .takes_value(true)
                         .requires("field")
                         .help("the new value of your field"),
+                )
+                .arg(
+                    Arg::with_name("bump")
+                        .long("bump")
+                        .short("b")
+                        .takes_value(true)
+                        .help("the type of bump you want (patch, minor, major)"),
                 ),
         )
         .get_matches();
@@ -62,14 +70,9 @@ pub fn start_command() -> Opts {
                 Some(t) => t.to_string(),
                 None => DEFAULT_TABLE.to_string(),
             },
-            field: match mtc.value_of("field") {
-                Some(t) => Some(t.to_string()),
-                None => None,
-            },
-            set: match mtc.value_of("set") {
-                Some(t) => Some(t.to_string()),
-                None => None,
-            },
+            field: mtc.value_of("field").map(|t| t.to_string()),
+            set: mtc.value_of("set").map(|t| t.to_string()),
+            bump: mtc.value_of("bump").map(|t| t.to_string()),
         };
     }
 
@@ -78,5 +81,6 @@ pub fn start_command() -> Opts {
         table: DEFAULT_TABLE.to_string(),
         field: None,
         set: None,
+        bump: None,
     }
 }
